@@ -1,6 +1,9 @@
 #ifndef GNOME_GPG_H
 #define GNOME_GPG_H
 
+#define GNOME_GPG_KEYID_ATTR  "openpgp-keyid"
+#define GNOME_GPG_USERID_ATTR "gnome-gpg-userid"
+
 /* a function to show a dialog and set it as transient for the xterm
  * that launched it. */
 void zenity_util_show_dialog (GtkWidget *dialog);
